<?php

namespace Luticate\Utils;

abstract class LuBusiness {
    public static $parameters = array();

    /**
     * @param string $name
     * @param mixed  $default
     * @return mixed
     */
    public static function getParam($name, $default = null)
    {
        return array_key_exists($name, self::$parameters) ? self::$parameters[$name] : $default;
    }

    /**
     * @param string[] $params
     * @return bool
     */
    public static function hasParam(array $params)
    {
        foreach ($params as $p) {
            if (!array_key_exists($p, self::$parameters)) {
                return false;
            }
        }
        return true;
    }

    /**
     * @param string $param
     * @param mixed $validate
     * @return string
     */
    public static function checkParam($param, $validate = null)
    {
        if (!self::hasParam(array($param)))
            abort(400, 'Missing parameter: ' . $param);
        $value = self::getParam($param);
        if ($validate != null) {
            if (is_callable($validate)) {
                $validate = $validate($value);
            }
            else {
                $validate = preg_match($validate, $value);
            }
            if (!$validate)
                abort(400, 'Bad parameter value: ' . $param);
        }
        return $value;
    }

    /**
     * @param string
     */
    public static function unauthorized($reason = 'Unauthorized')
    {
        abort(401, $reason);
    }

    /**
     * @param string
     */
    public static function notFound($reason = 'Resource not found')
    {
        abort(404, $reason);
    }

    /**
     * @param string
     */
    public static function badInput($reason = 'Invalid user input')
    {
        abort(400, $reason);
    }

    /**
     * @param $param string
     * @param $values string[]
     * @return string
     */
    public static function getParamInArray($param, $values)
    {
        $value = self::getParam($param);
        if (is_null($value) || !in_array($value, $values))
            $value = $values[0];
        return $value;
    }

    /**
     * @param $param string
     * @param $default int
     * @return int
     */
    public static function getParamInt($param, $default = 0)
    {
        $value = self::getParam($param);
        if (!is_null($value) && is_numeric($value))
            return (int)$value;
        return $default;
    }

    /**
     * @param $id int
     * @return LuDbo|null
     */
    public static function getById($id)
    {
        $data = static::getDataAccess()->getById($id);
        if (is_null($data))
            self::notFound(static::getResourceName() . " not found");
        return $data;
    }

    /**
     * @param $id int
     * @return true
     */
    public static function deleteById($id)
    {
        $res = static::getDataAccess()->deleteById($id);
        if (!$res)
            self::notFound(static::getResourceName() . " not found");
        return true;
    }

    /**
     * @return LuDataAccess
     */
    protected static function getDataAccess()
    {
        return null;
    }

    public static function getAll($page = 0, $perPage = PHP_INT_MAX, $query = "")
    {
        return static::getDataAccess()->getAll($page, $perPage, $query);
    }

    public static function getResourceName()
    {
        $match = [];
        preg_match('/([^\\\\]*)Business$/', get_called_class(), $match);
        return $match[1];
    }
}
